@@ -56,6 +56,11 @@ urlpatterns = [
         login_required(views.SexEntry.as_view()),
         name="set_sex",
     ),
+    re_path(
+        r"^animals/(?P<uuid>[a-f0-9\-]{36})/reserve/$",
+        login_required(views.ReservationEntry.as_view()),
+        name="update_reservation",
+    ),
     re_path(
         r"^animals/(?P<uuid>[a-f0-9\-]{36})/new-clutch/$",
         login_required(views.ClutchEntry.as_view()),
@@ -101,6 +106,11 @@ urlpatterns = [
     re_path(
         r"^set-sex/$", login_required(views.SexEntry.as_view()), name="set_sex"
     ),
+    re_path(
+        r"^reserve/$",
+        login_required(views.ReservationEntry.as_view()),
+        name="update_reservation",
+    ),
     # api
     re_path(r"^api/info/$", views.api_info, name="api_info"),
     re_path(r"^api/animals/$", views.APIAnimalsList.as_view(), name="animals_api"),
